import Bio
import sys
import math
from Bio import SeqIO


#declare input
#files = ["ENCFF002DHJ"]
files = ["ENCFF002DHA", "ENCFF002DHB", "ENCFF002DHC", "ENCFF002DHD", "ENCFF002DHE", "ENCFF002DHF", "ENCFF002DHG", "ENCFF002DHH", "ENCFF002DHI"]
sequence = "TGCATG"
reach=3

L_w=len(sequence)


#define nucleic acid dictionary
nucl_dict = {"A" : 0, "C" : 1, "G" : 2, "T" : 3}
inv_nucl_dict = {0 : "A", 1 : "C", 2 : "G", 3 : "T"}



#create arrays for nucleotide counts
upstream_counts = [0.0 for i in range(0,4*reach)]
downstream_counts = [0.0 for i in range(0,4*reach)]



#-------------------------------
#START OF THE SCRIPT
#-------------------------------
for data_file in files:
	for read in SeqIO.parse(data_file+".fastq","fastq"):
		s = read.seq
		
		ind = s.find(sequence)
		if ind == -1 or "N" in s:
			continue
		elif reach <= ind < len(s) - L_w - reach:
			for r in range(0,reach):
				upstream_counts[nucl_dict[s[ind-reach+r]]*reach+r] += 1.0
				downstream_counts[nucl_dict[s[ind+L_w+r]]*reach+r] += 1.0
			
		
	

#normalize
for i in range(0,reach):
	upstream_norm = 0.0
	downstream_norm = 0.0
	for j in range(0,4):
		upstream_norm += upstream_counts[j*reach+i]
		downstream_norm += downstream_counts[j*reach+i]
	for j in range(0,4):
		upstream_counts[j*reach+i] /= upstream_norm
		downstream_counts[j*reach+i] /= downstream_norm


#print result
print("Sequence bias around "+sequence+":")

for j in range(0,4):
	for i in range(0,reach):
		print(upstream_counts[j*reach+i],end="\t")
	for i in range(0,reach):
		print(downstream_counts[j*reach+i],end="\t")
	print("")
